@@ -4,6 +4,7 @@ import android.content.Intent
 import android.net.Uri
 import android.support.annotation.MainThread
 import android.support.v4.content.LocalBroadcastManager
+import android.support.v7.preference.PreferenceManager
 import android.text.TextUtils
 import android.util.Log
 import android.widget.Toast
@@ -34,7 +35,7 @@ class PlaylistManager(val service: PlaybackService) : MediaWrapperList.EventList
 
     private val medialibrary by lazy(LazyThreadSafetyMode.NONE) { Medialibrary.getInstance() }
     val player by lazy(LazyThreadSafetyMode.NONE) { PlayerController() }
-    private val settings by lazy(LazyThreadSafetyMode.NONE) { VLCApplication.getSettings() }
+    private val settings by lazy(LazyThreadSafetyMode.NONE) { PreferenceManager.getDefaultSharedPreferences(service) }
     private val ctx by lazy(LazyThreadSafetyMode.NONE) { VLCApplication.getAppContext() }
     private val mediaList = MediaWrapperList()
     var currentIndex = -1
@@ -51,7 +52,8 @@ class PlaylistManager(val service: PlaybackService) : MediaWrapperList.EventList
     var savedTime = 0L
     private var random = Random(System.currentTimeMillis())
     private var newMedia = false
-    @Volatile var expanding = false
+    @Volatile
+    private var expanding = false
 
     fun hasMedia() = mediaList.size() != 0
     fun hasCurrentMedia() = isValidPosition(currentIndex)
@@ -284,6 +286,7 @@ class PlaylistManager(val service: PlaybackService) : MediaWrapperList.EventList
                 newMedia = true
             }
         } else { //Start VideoPlayer for first video, it will trigger playIndex when ready.
+            player.stop()
             VideoPlayerActivity.startOpened(ctx, mw.uri, currentIndex)
         }
     }
@@ -304,7 +307,7 @@ class PlaylistManager(val service: PlaybackService) : MediaWrapperList.EventList
             LocalBroadcastManager.getInstance(service).sendBroadcast(
                     VideoPlayerActivity.getIntent(Constants.PLAY_FROM_SERVICE,
                             media, false, currentIndex))
-        } else if (!player.switchToVideo) {//Start the video player
+        } else if (!player.switchToVideo) { //Start the video player
             VideoPlayerActivity.startOpened(VLCApplication.getAppContext(), media.uri, currentIndex)
             if (!hasRenderer) player.switchToVideo = true
         }
@@ -500,20 +503,21 @@ class PlaylistManager(val service: PlaybackService) : MediaWrapperList.EventList
      */
     @MainThread
     private suspend fun expand(updateHistory: Boolean): Int {
+        val index = currentIndex
         val ml = player.expand()
         var ret = -1
 
         if (ml != null && ml.count > 0) {
             val mrl = if (updateHistory) getCurrentMedia()?.location else null
-            mediaList.remove(currentIndex)
+            mediaList.remove(index)
             for (i in ml.count - 1 downTo 0) {
                 val child = ml.getMediaAt(i)
                 child.parse()
-                mediaList.insert(currentIndex, MediaWrapper(child))
+                mediaList.insert(index, MediaWrapper(child))
                 child.release()
             }
             if (mrl !== null && ml.count == 1) medialibrary.addToHistory(mrl, getCurrentMedia()!!.title)
-            ret = currentIndex
+            ret = index
         }
         ml?.release()
         return ret
